Logger class

Constructors

Logger(IOSink _output)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSilent ↔ bool
getter/setter pair
isVerbose ↔ bool
getter/setter pair
progress → Progress
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirm(String message, {bool defaultValue = false}) → bool
Prompts user with a yes/no question.
delayed(String message) → void
error(String message) → void
flush([void print(String)?]) → void
info(String message) → void
infoVerbose(String message) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printConfig(Map<String, Object?> config) → void
success(String message) → void
toString() → String
A string representation of this object.
inherited
updateAvailable(String version, String newVersion, String changelogLink) → void
warn(String message, {String tag = 'WARN'}) → void
write(String message) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited