MetricDocumentation class

Represents any metric documentation.

Constructors

MetricDocumentation({required String name, required String shortName, required EntityType measuredType, required num recommendedThreshold})
Initialize a newly created MetricDocumentation.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
measuredType → EntityType
The type of entities which will be measured by the metric.
final
name → String
The name of the metric.
final
recommendedThreshold → num
The recommended threshold value for this metric.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String
The short name of the metric.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited