suggestPrivateMembers property

bool? suggestPrivateMembers
final

Whether public declarations that are only ever referenced from within their own declaring library should be reported as candidates for being made private.

Independent from the two flags above: this reports declarations that are used, so it says nothing about dead code and can be enabled on its own.

Implementation

final bool? suggestPrivateMembers;