kind property
What is being reported about the declaration.
Defaults to UnusedCodeIssueKind.unused, which is what the check reported before could be private suggestions existed.
Implementation
final UnusedCodeIssueKind kind;
What is being reported about the declaration.
Defaults to UnusedCodeIssueKind.unused, which is what the check reported before could be private suggestions existed.
final UnusedCodeIssueKind kind;