suppressed method
Returns a copy of this value with level overridden to MetricValueLevel.none.
Used when the metric is suppressed via an ignore comment.
Implementation
MetricValue<T> suppressed() => MetricValue(
metricsId: metricsId,
documentation: documentation,
value: value,
unitType: unitType,
level: MetricValueLevel.none,
comment: comment,
recommendation: recommendation,
context: context,
);