UnusedCodeAnalysisConfig class

Represents converted unused code config which contains parsed entities.

Constructors

UnusedCodeAnalysisConfig(Iterable<Glob> globalExcludes, Iterable<Glob> analyzerExcludedPatterns, {required bool isMonorepo, required bool analyzePrivateMembers, required bool analyzePublicMembers})
const

Properties

analyzeMembers bool
Whether members of type declarations take part in the analysis at all, either as candidates or as recorded usages.
no setter
analyzePrivateMembers bool
final
analyzePublicMembers bool
final
analyzerExcludedPatterns Iterable<Glob>
final
globalExcludes Iterable<Glob>
final
hashCode int
The hash code for this object.
no setterinherited
isMonorepo bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited