UnusedCodeConfig class

Represents raw unused code config which can be merged with other raw configs.

Bool flags are bool? so an override can explicitly disable what the base config enabled.

Constructors

UnusedCodeConfig({required Iterable<String> excludePatterns, required Iterable<String> analyzerExcludePatterns, required bool? isMonorepo, required bool? shouldPrintConfig, required bool? analyzePrivateMembers, required bool? analyzePublicMembers, required bool? suggestPrivateMembers})
const
UnusedCodeConfig.fromAnalysisOptions(AnalysisOptions options)
Creates the config from analysis options.
factory
UnusedCodeConfig.fromArgs(Iterable<String> excludePatterns, {required bool? isMonorepo, required bool? shouldPrintConfig, required bool? analyzePrivateMembers, required bool? analyzePublicMembers, required bool? suggestPrivateMembers})
Creates the config from cli args. Pass null for an unparsed flag.
factory

Properties

analyzePrivateMembers → bool?
Whether unused private members in type declarations (methods, fields, getters, setters and named constructors) should be reported in addition to top-level declarations.
final
analyzePublicMembers → bool?
Whether unused public members in type declarations should be reported in addition to top-level declarations.
final
analyzerExcludePatterns → Iterable<String>
final
excludePatterns → Iterable<String>
final
hashCode → int
The hash code for this object.
no setterinherited
isMonorepo → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldPrintConfig → bool?
final
suggestPrivateMembers → bool?
Whether public declarations that are only ever referenced from within their own declaring library should be reported as candidates for being made private.
final

Methods

merge(UnusedCodeConfig overrides) → UnusedCodeConfig
Merges two configs into a single one.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited